# `m`

`m` is a simple CLI application that I personally use when developing projects.
It is written in Python and is designed to be easy to extend.

## Installation

Since this package is a CLI application, it is recommended to install it
globally with `uv` or `pipx`:

```sh
uv tool install muspi-merol[all]
```

or

```sh
pipx install muspi-merol[all]
```

You can also install it with `pip`:

```sh
pip install muspi-merol[all]
```

## Usage

You can find the usage information by running:

```sh
m --help
```
